@@ -95,7 +95,7 @@
 /*
  * addr.y -- RFC 822 address parser
  * Ken Murchison
- * $Id: addr.c 125 2007-10-10 08:04:14Z sodabrew $
+ * $Id: addr.c 143 2008-11-13 03:58:25Z sodabrew $
  */
 /***********************************************************
         Copyright 1999 by Carnegie Mellon University
@@ -144,7 +144,7 @@ OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 /* There are global to this file */
 char *libsieve_addrptr;          /* pointer to sieve string for address lexer */
-struct sieve2_context *libsieve_parse_context;
+extern struct sieve2_context *libsieve_parse_context;
 static struct address *addr = NULL;
 static struct mlbuf *ml = NULL;
 
