@@ -94,7 +94,7 @@
 
 /* header.y -- RFC 2/822 Header Parser
  * Aaron Stone
- * $Id: header.c 125 2007-10-10 08:04:14Z sodabrew $
+ * $Id: header.c 143 2008-11-13 03:58:25Z sodabrew $
  */
 /* * * *
  * Copyright 2005 by Aaron Stone
@@ -1612,7 +1612,7 @@ yyreturn:
 
 
 /* copy header error message into buffer provided by sieve parser */
-void libsieve_headererror(const char *s)
+void libsieve_headererror(char *s)
 {
     extern int libsieve_headerlineno;
     TRACE_DEBUG( "Header parse error on line %d: %s",
